#!/usr/bin/env python
########################################################################################################################
# Description:  some utility functions for py.test                                                                     #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started: 20160929                                                                                               #
########################################################################################################################


#########################
#     Setup Stuff       #
#########################
import logging
utilLog = logging.getLogger('myLogger')
utilLog.setLevel(logging.INFO)


############################################################
#                 The assert functions                    #
############################################################

def AssertTest(testObject, assertTest, message, assertError="yes"):
    """
    This method does an assertion test and logs the resluts

    :param testObject: --REQUIRED-- the object created by the test
    :param assertTest: --REQUIRED-- the assert statement to tesat for
    :param message: --REQUIRED-- the messaage logged to explain the issue
    :param assertError: Raise an assertion error.    Default YES
    """

    if not eval(assertTest):        
        utilLog.error("= = = = = = = = = = = Error = = = = = = = = = = = ")
        utilLog.error(message)
        utilLog.error("The method used is: " + testObject.method)
        utilLog.error("The url called is: " + testObject.address)
        utilLog.error("The header sent is: " + str(testObject.header))
        utilLog.error("The data sent is: " + str(testObject.data))

        try:
            utilLog.error("The return header was: " + str(testObject.return_headers))
        except:
            utilLog.error("The return header was not returned")

        try:
            utilLog.error("The data returned was: " + str(testObject.content))
        except:
            utilLog.error("The return data was not returned")

        utilLog.error("= = = = = = = = = = Test Failed = = = = = = = = = = \n")

        if assertError == "yes":
            raise AssertionError
        else:
            return "failed"


def AssertSearch(testObject, searchTerm, assertError="yes"):
    """
    This method searches for a string in the return content and logs the resluts

    :param testObject: --REQUIRED-- the object created by the test
    :param searchTerm: --REQUIRED-- the text to search for
    :param assertError: Raise an assertion error.    Default YES
    """
  
    # - 2Do - add ability to input a list of search terms
    # - 2Do - add option to log INFO that the search term found
    # - 2Do - add option for regx search

    if not testObject.content.find(searchTerm) > 0:
        utilLog.error("= = = = = = = = = = = Error = = = = = = = = = = = ")
        errorMessage = "Could NOT find '" + searchTerm + "' in the returned content"
        utilLog.error(errorMessage)
        utilLog.error("The method used is: " + testObject.method)
        utilLog.error("The url called is: " + testObject.address)
        utilLog.error("The header sent is: " + str(testObject.header))
        utilLog.error("The data sent is: " + str(testObject.data))

        try:
            utilLog.error("The return header was: " + str(testObject.return_headers))
        except:
            utilLog.error("The return header was not returned")

        try:
            utilLog.error("The data returned was: " + str(testObject.content))
        except:
            utilLog.error("The return data was not returned")

        utilLog.error("= = = = = = = = = = Test Failed = = = = = = = = = = \n")

        if assertError == "yes":
            raise AssertionError
        else:
            return "failed"


# End of File
# ==============================================================================


#!/usr/bin/env python
########################################################################################################################
# Description:  Test clase file for WordPress RESTful API                                                              #
# This is an example of how a restful api class file should be written                                                 #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started: some time before 20160901                                                                              #
########################################################################################################################


#########################
#     Setup stuff       #
#########################
import pytest

# import local code
import repackage
repackage.up(2)
from spat4apitesting import API

default_header = ""


############################################################
#                    Test Classes                          #
############################################################
class GetAllUsers(API):
    """
    This class uses the 'user' endpoint to get a list of all of the users
    """
    def __init__(self, user, password, env):
        """
        :param user: --REQUIRED-- the user to log in with
        :param password: --REQUIRED-- the password to log in with
        :param env: --REQUIRED-- the environment you are testing it
        """
        endpoint = "/wp-json/wp/v2/users"
        self.address = env + endpoint
        self.method = "GET"
        self.user = user
        self.password = password
        self.data = ""
        self.header = default_header
        self.params = ""


class GetUser(API):
    """
    This Class gets the current user info
    """
    def __init__(self, user, password, env):
        """
        :param user: --REQUIRED-- the user to log in with
        :param password: --REQUIRED-- the password to log in with
        :param env: --REQUIRED-- the environment you are testing it
        """
        endpoint = "/wp-json/wp/v2/users/me"
        self.address = env + endpoint
        self.method = "GET"
        self.user = user
        self.password = password
        self.data = ""
        self.header = default_header
        self.params = ""


class GetAllPosts(API):

    def __init__(self, env):
        endpoint = "/wp-json/wp/v2/posts"
        self.address = env + endpoint
        self.method = "GET"
        self.password = ""
        self.user = ""
        self.data = ""
        self.header = default_header
        self.params = ""


class GetPosts(API):

    def __init__(self, env):
        endpoint = "/wp-json/wp/v2/posts"
        self.address = env + endpoint
        self.method = "GET"
        self.password = ""
        self.user = ""
        self.data = ""
        self.header = default_header
        self.params = ""


class GetPosts_bad(API):

    def __init__(self, env):
        """
        GetPosts_bad has a bad URL so it will always fail
        This is for testing of the test system only
        """
        endpoint = "/wp-json/wp/v123/posts"
        self.address = env + endpoint
        self.method = "GET"
        self.password = ""
        self.user = ""
        self.data = ""
        self.header = default_header
        self.params = ""


class PostNewPost(API):

    def __init__(self, user, data, env, password="password"):
        endpoint = "/wp-json/wp/v2/posts"
        self.address = env + endpoint
        self.method = "POST"
        self.user = user
        self.password = password
        self.data = data
        self.header = default_header
        self.params = ""


class GetAllCategories(API):


    def __init__(self, env):
        endpoint = "/wp-json/wp/v2/categories"
        self.address = env + endpoint
        self.method = "GET"
        self.password = ""
        self.user = ""
        self.data = ""
        self.header = default_header
        self.params = ""


class PostNewPage(API):

    def __init__(self, user, data, env, password="password"):
        endpoint = "/wp-json/wp/v2/pages"
        self.address = env + endpoint
        self.method = "POST"
        self.user = user
        self.password = password
        self.data = data
        self.header = default_header
        self.params = ""


class PostUpdatePage(API):

    def __init__(self, user, page_id, data, env, password="password"):
        endpoint = "/wp-json/wp/v2/pages/" + str(page_id)
        self.address = env + endpoint
        self.method = "POST"
        self.user = user
        self.password = password
        self.data = data
        self.header = default_header
        self.params = ""


class GetPages(API):

    def __init__(self, env, data=''):
        endpoint = "/wp-json/wp/v2/pages/"
        self.address = env + endpoint
        self.method = "GET"
        self.user = ""
        self.password = ""
        self.data = data
        self.header = default_header
        self.params = ""


# End of File
# ==============================================================================



#! /usr/bin/env python
########################################################################################################################
# Description:  This file is run before every test suite to do some setup work.                                        #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started: 20161028                                                                                               #
########################################################################################################################


#########################
#     Setup Stuff       #
#########################
import os
import csv
import datetime
import logging
from . util import *


########################################
#  Process environment file variables  #
########################################
def get_env_var():
  """
  This sets up the environment variables from the env file.
  """
  # get the current env that is bing tested
  if os.getenv("pyTestEnv"):
      envFile = os.environ["pyTestEnv"]
      myLogger.debug("The env CSV file is: " + envFile)
  else:
      msg =  "Could not find the environment file parameter.  There for tests can not be run."
      myLogger.error(msg=msg)
      print(msg)
      exit()

  # read csv file into env. variables 
  readCsvFile = csv.reader(open(envFile, 'r'))
  varDict = {}
  for row in readCsvFile:
      csvKey, csvValue = row
      myLogger.debug("Adding this variable: " + str(csvKey))
      os.environ[str(csvKey)] = str(csvValue)
    

########################################
#     Process additional variables     #
########################################    
#  The following is for processing additional global variables.
#  This is so that you can have variables that are not associated
#  with the environment, but are global to all tests.

def get_additional_var():
  """
  Sets up additonal environment variables from the optional file
  """
  # get the current env that is bing tested
  if not os.path.isfile(varsFile):
      msg = "Could not find '" + str(varsFile) + "', the additional variables file.  There for tests can not be run."
      myLogger.error(msg=msg)
      print(msg)
      exit()
  else:

      # read vars file into dictionary
      readVarsFile = csv.reader(open(varsFile, 'r'))
      varDict2 = {}
      for row in readVarsFile:
          csvKey, csvValue = row
          myLogger.debug("Adding optional variable: " + str(csvKey))
          os.environ[str(csvKey)] = str(csvValue)  
    

########################################
#          Setup Logging               #
########################################
# create time stamp for logging
now = datetime.datetime.now()
time = now.strftime("%d%H%M%S")
number_name = time

# build loggers
myLogger = logging.getLogger()

# Check to see if we are using DEBUG or INFO
if os.getenv("pyTestDebug"):
    myLogger.setLevel(logging.DEBUG)
    l_level = "DEBUG"
else:
    myLogger.setLevel(logging.INFO)
    l_level = "INFO"

# Get full path to log file    
testfilename =   os.environ["pyTestFile"].strip(".py").replace('/','-') 
log_file_name = "logs/{time}-{filename}.log".format(time=time, filename=testfilename)

log_handler = logging.FileHandler(log_file_name)
log_handler.setLevel(logging.NOTSET)
myLogger.addHandler(log_handler)

# build log file header
formatter0 = logging.Formatter()
log_handler.setFormatter(formatter0)
myLogger.info("============================================================")
myLogger.info("  The following is some basic info on this log file")
myLogger.info("------------------------------------------------------------")
myLogger.info("The log file is: " + log_file_name)

# set envrionment variabless
get_env_var()
myLogger.debug("The environment variables are: " + str(os.environ))

# see if we have optional varialbes and add them
if os.getenv("pyTestVars"):
      varsFile = os.environ["pyTestVars"]
      myLogger.debug("The optional variables CSV file is: " + varsFile)
      get_additional_var()

# finish the log header 
formatter1 = logging.Formatter('Log file created at: %(asctime)s \nThe test file is: ' +  os.environ["pyTestFile"]  + '\nThe log level is: ' + l_level)
log_handler.setFormatter(formatter1)
myLogger.info("")

# setup header for regular logging statements
log_handler.setFormatter(formatter0)
myLogger.info("\nDate        Time         Line   Level     Message")
myLogger.info("============================================================")

# set format for regular logging statements
formatterFinal = logging.Formatter('%(asctime)s - %(lineno)d  - %(levelname)s - %(message)s')
log_handler.setFormatter(formatterFinal)




# End of File
# ==============================================================================